@@ -2,6 +2,9 @@ package EventStore::Tiny;
 
 use strict;
 use warnings;
+use feature 'signatures';
+no warnings 'experimental::signatures';
+use Carp;
 
 use EventStore::Tiny::Logger;
 use EventStore::Tiny::Event;
@@ -14,7 +17,7 @@ use IO::File;
 use YAML::Syck;     # Exports Dump(), Load()
 use Data::Compare;  # Exports Compare()
 
-our $VERSION = '0.6';
+our $VERSION = '0.7';
 
 use Class::Tiny {
     events          => sub {EventStore::Tiny::EventStream->new(
@@ -26,8 +29,7 @@ use Class::Tiny {
     cache_distance  => 0, # Default: store snapshot each time. no caching: undef
 }, '_cached_snapshot';
 
-sub import_events {
-    my ($self, $fn) = @_;
+sub import_events ($self, $fn) {
 
     # Rerieve
     my $file    = IO::File->new($fn, 'r');
@@ -51,8 +53,7 @@ sub import_events {
     $self->events($stream);
 }
 
-sub export_events {
-    my ($self, $fn) = @_;
+sub export_events ($self, $fn) {
 
     # Simplify
     my @events = ();
@@ -71,23 +72,20 @@ sub export_events {
     $file->close;
 }
 
-sub register_event {
-    my ($self, $name, $transformation) = @_;
+sub register_event ($self, $name, $transformation) {
 
     # Register transformation
     $self->trans_store->set($name => $transformation);
 }
 
-sub event_names {
-    my $self = shift;
+sub event_names ($self) {
     return [$self->trans_store->names];
 }
 
-sub store_event {
-    my ($self, $name, $data) = @_;
+sub store_event ($self, $name, $data = undef) {
 
     # Lookup event type
-    die "Unknown event: $name!\n"
+    croak "Unknown event: $name!\n"
         unless defined $self->trans_store->get($name);
 
     # Create event
@@ -101,18 +99,13 @@ sub store_event {
     return $self->events->add_event($event);
 }
 
-sub init_state {
-    my $self = shift;
+sub init_state ($self) {
 
     # Clone init data
     return clone($self->init_data);
 }
 
-sub snapshot {
-    my ($self, $timestamp) = @_;
-
-    # Work on latest timestamp if not specified
-    $timestamp //= $self->events->last_timestamp;
+sub snapshot ($self, $timestamp = $self->events->last_timestamp) {
     my $es = $self->events->before($timestamp);
 
     # Check if the cached snapshot can be used
@@ -157,8 +150,7 @@ sub snapshot {
     return $snapshot;
 }
 
-sub is_correct_snapshot {
-    my ($self, $snapshot) = @_;
+sub is_correct_snapshot ($self, $snapshot) {
 
     # Replay events before snapshot time
     my $our_sn = $self->snapshot($snapshot->timestamp);
@@ -177,33 +169,29 @@ sub is_correct_snapshot {
 
 EventStore::Tiny - A minimal event sourcing framework.
 
-B<ATTENTION>: as of version 0.6 there is an API change regarding serialization which breaks existing applications that use serialization as well as their existing event stores.
-
 =begin html
 
 <p>
 
-<a href="https://badge.fury.io/pl/EventStore-Tiny">
-    <img alt="CPAN version" src="https://badge.fury.io/pl/EventStore-Tiny.svg"></a>
-<a href="https://travis-ci.org/memowe/EventStore-Tiny">
-    <img alt="Travis CI tests" src="https://travis-ci.org/memowe/EventStore-Tiny.svg?branch=master"></a>
-<a href="https://codecov.io/gh/memowe/EventStore-Tiny">
-    <img alt="Codecov test coverage" src="https://codecov.io/gh/memowe/EventStore-Tiny/branch/master/graph/badge.svg"></a>
-<a href="https://coveralls.io/github/memowe/EventStore-Tiny?branch=master">
-    <img alt="Coveralls test coverage" src="https://coveralls.io/repos/github/memowe/EventStore-Tiny/badge.svg?branch=master"></a>
-<a href="http://cpants.cpanauthors.org/dist/EventStore-Tiny">
-    <img alt="CPANTS kwalitee score" src="https://cpants.cpanauthors.org/dist/EventStore-Tiny.png"></a>
-
-<br><br>
-
-<a href="http://www.cpantesters.org/distro/E/EventStore-Tiny.html?distmat=1">
-    <img alt="CPAN testers reports" src="https://img.shields.io/badge/testers-reports-blue.svg"></a>
-<a href="http://matrix.cpantesters.org/?dist=EventStore-Tiny">
-    <img alt="CPAN testers matrix" src="https://img.shields.io/badge/testers-matrix-blue.svg"></a>
 <a href="https://github.com/memowe/EventStore-Tiny">
     <img alt="GitHub repository" src="https://img.shields.io/badge/github-code-blue.svg"></a>
 <a href="https://github.com/memowe/EventStore-Tiny/issues">
     <img alt="GitHub issue tracker" src="https://img.shields.io/badge/github-issues-blue.svg"></a>
+<a href="https://badge.fury.io/pl/EventStore-Tiny">
+    <img alt="CPAN version" src="https://badge.fury.io/pl/EventStore-Tiny.svg"></a>
+<a href="http://www.cpantesters.org/distro/E/EventStore-Tiny.html?distmat=1">
+    <img alt="CPAN testers reports" src="https://img.shields.io/badge/testers-reports-blue.svg"></a>
+<a href="http://matrix.cpantesters.org/?dist=EventStore-Tiny">
+    <img alt="CPAN testers matrix" src="https://img.shields.io/badge/testers-matrix-blue.svg"></a>
+
+<br><br>
+
+<a href="https://github.com/memowe/EventStore-Tiny/actions/workflows/linux-tests.yml">
+    <img alt="Linux tests" src="https://github.com/memowe/EventStore-Tiny/actions/workflows/linux-tests.yml/badge.svg?branch=main"></a>
+<a href="https://github.com/memowe/EventStore-Tiny/actions/workflows/mac-tests.yml">
+    <img alt="Mac OS tests" src="https://github.com/memowe/EventStore-Tiny/actions/workflows/mac-tests.yml/badge.svg?branch=main"></a>
+<a href="https://github.com/memowe/EventStore-Tiny/actions/workflows/windows-tests.yml">
+    <img alt="Windows tests" src="https://github.com/memowe/EventStore-Tiny/actions/workflows/windows-tests.yml/badge.svg?branch=main"></a>
 
 </p>
 
@@ -216,8 +204,7 @@ B<ATTENTION>: as of version 0.6 there is an API change regarding serialization w
     my $store = EventStore::Tiny->new;
 
     # Register event type
-    $store->register_event(UserAdded => sub {
-        my ($state, $data) = @_;
+    $store->register_event(UserAdded => sub ($state, $data) {
 
         # Use $data to inject the new user into the given $state
         $state->{users}{$data->{id}} = {
@@ -309,8 +296,7 @@ Serializes the event stream to the file system. It can be imported back via L</i
 
 =head3 register_event
 
-    $store->register_event(ConnectionRemoved => sub {
-        my ($state, $data) = @_;
+    $store->register_event(ConnectionRemoved => sub ($state, $data) {
         # Change $state depending on $data (by side-effect)
     });
 
@@ -356,7 +342,7 @@ Returns the internal L<EventStore::Tiny::TransformationStore> object that stores
 
     my $state = $store->init_state;
 
-Returns a cloned copy of the ininitial state all events are applied on, which was defined by L</init_data> as a hashref.
+Returns a cloned copy of the initial state all events are applied on, which was defined by L</init_data> as a hashref.
 
 =head2 SLACK MODE
 
@@ -378,7 +364,7 @@ EventStore::Tiny's source repository is hosted on L<GitHub|https://github.com/me
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2018 L<Mirko Westermeier|http://mirko.westermeier.de> (L<@memowe|https://github.com/memowe>, L<mirko@westermeier.de|mailto:mirko@westermeier.de>)
+Copyright (c) 2018-2021 L<Mirko Westermeier|http://mirko.westermeier.de> (L<@memowe|https://github.com/memowe>, L<mirko@westermeier.de|mailto:mirko@westermeier.de>)
 
 Released under the MIT License (see LICENSE.txt for details).
 
